# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.12.1] 2024-09-25

### Added

### Changed

### Removed


## [0.12.0] 2024-09-11

### Added

### Changed

### Removed


## [0.11.0] 2024-09-02

### Added

### Changed

### Removed


## [0.10.0] 2024-03-22

### Added

### Changed

### Removed


## [0.9.0] 2024-02-17

### Added

* AIXD pre-release version
